@@ -17,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.2.13.1'
+    return '2.2.14'
 
 
 def f_debug():
@@ -349,10 +349,14 @@ def f_debug():
 
 
         elif b[0] in ["version", "VERSION", "V", "v"]:
-
+            import sys
             print(logs.日志(f"Fishconsole fcv_debug [ 2.0 ]", "蓝色"))
             print(logs.日志(f"Fishconsole版本：{version()}     -    {pkg_resources.get_distribution('Fishconsole').version}","蓝色"))
+            print(logs.日志(f"Fishconsole 安装位置：{sys.path[0]}","蓝色"))
+            print(logs.日志(f"python版本：{sys.version }（推荐python3.8x）","蓝色"))
             print(logs.日志(f"制作者：鱼几斤","蓝色"))
+            print(logs.日志(f"项目地址：https://pypi.org/project/Fishconsole/", "蓝色"))
+
 
         elif b[0] in ["pip", "PIP"]:
             未选触发器 = True
